@@ -26,8 +26,8 @@ from hspylib.addons.widman.widget import Widget
 from hspylib.core.enums.exit_status import ExitStatus
 from hspylib.core.exception.exceptions import WidgetExecutionError
 from hspylib.core.tools.commons import sysout
-from hspylib.modules.cli.application.argparse.argument_parser import HSArgumentParser
-from hspylib.modules.cli.application.version import Version
+from hspylib.modules.application.argparse.argument_parser import HSArgumentParser
+from hspylib.modules.application.version import Version
 from hspylib.modules.cli.icons.font_awesome.widget_icons import WidgetIcons
 from hspylib.modules.cli.tui.extra.minput.input_validator import InputValidator
 from hspylib.modules.cli.tui.extra.minput.minput import MenuInput, minput
