@@ -15,5 +15,14 @@ class CliApplication(Application):
     def _cleanup(self) -> None:
         pass
 
-    def __init__(self, name: str, version: Version):
-        super().__init__(name, version)
+    def __init__(
+        self,
+        name: str,
+        version: Version,
+        description: str = None,
+        usage: str = None,
+        epilog: str = None,
+        resource_dir: str = None,
+        log_dir: str = None):
+
+        super().__init__(name, version, description, usage, epilog, resource_dir, log_dir)
